
from setuptools import setup

setup(
    name='py-tsharp',
    version='1.0.2',
    description='A CLI for The T# Language (Made by me)',
    long_description='I will update this later',
    packages=["tX", "pytsharp_utils"]
    )

